<div class="form-group clearfix">
    <label class="col-md-3 control-label" for="fleetComms">Fleet Comms</label>
    <div class="col-md-9">
        <input id="fleetComms" name="fleetComms" type="text" class="form-control input-md">
    </div>
</div>
