<div class="form-group clearfix">
    <label class="col-md-3 control-label" for="fleetSrp">SRP</label>
    <div class="col-md-9">
        <select id="fleetSrp" name="fleetSrp" class="form-control">
            <option value="">Please select</option>
            <option value="Yes">Yes</option>
            <option value="No">No</option>
        </select>
    </div>
</div>
