<div class="form-group clearfix">
    <label class="col-md-3 control-label" for="formupTime">Formup Time<br><span class="small">Always use Eve Time</span></label>
    <div class="col-md-9">
        <input id="formupTime" name="formupTime" type="text" class="form-control input-md" disabled>
        <span class="small">To enable this field, either make it a Pre-Ping (checkbox above) or uncheck "Formup NOW" (checkbox below).</span>
        {% if timezones_installed %}
            <span class="small">Timezones module is installed. Link to time zone conversion will be added automatically if you set a date and time here.</span>
        {% endif %}
        <div class="checkbox">
            <label for="formupTimeNow">
                <input type="checkbox" name="formupTimeNow" id="formupTimeNow" value="1" checked> Formup NOW<br><span class="small">If this checkbox is active, formup time will be set to "NOW" and the time in the field above (if any is set) will be ignored.</span>
            </label>
        </div>
    </div>
</div>
