{% extends 'discordpingformatter/base.html' %}
{% load i18n %}
{% load humanize %}
{% load static %}

{% block details %}
    <div class="aa-discord-ping-formatter row">
        <div class="col-md-6">
            {% include "discordpingformatter/form.html" %}
        </div>

        <div class="col-md-6">
            {% include 'discordpingformatter/ping.html' %}
        </div>
    </div>
{% endblock %}

{% block extra_javascript %}
    <script type="text/javascript" src="{% static 'discordpingformatter/js/copy-to-clipboard/copy-to-clipboard.min.js' %}"></script>
    <script type="text/javascript" src="{% static 'discordpingformatter/js/discordpingformatter.min.js' %}"></script>

    {% include 'bundles/jquery-datetimepicker-js.html' %}
{% endblock %}

{% block extra_css %}
    {% include 'bundles/jquery-datetimepicker-css.html' %}
{% endblock %}

{% block extra_script %}
    $('#formupTime').datetimepicker({
        lang: '{{ LANGUAGE_CODE }}',
        maskInput: true,
        format: 'Y-m-d H:i',
        dayOfWeekStart: 1,
        step: 15
    });
{% endblock extra_script %}
